#define YPMAXRECORD 1024
#define YPMAXDOMAIN 64
#define YPMAXMAP 64
#define YPMAXPEER 64

enum YPstat {
	YP_TRUE = 1,
	YP_NOMORE = 2,
	YP_FALSE = 0,
	YP_NOMAP = -1,
	YP_NODOM = -2,
	YP_NOKEY = -3,
	YP_BADOP = -4,
	YP_BADDB = -5,
	YP_YPERR = -6,
	YP_BADARGS = -7,
	YP_VERS = -8,
};
typedef enum YPstat YPstat;
bool_t xdr_YPstat();


enum YPxfrstat {
	YPXFR_SUCC = 1,
	YPXFR_AGE = 2,
	YPXFR_NOMAP = -1,
	YPXFR_NODOM = -2,
	YPXFR_RSRC = -3,
	YPXFR_RPC = -4,
	YPXFR_MADDR = -5,
	YPXFR_YPERR = -6,
	YPXFR_BADARGS = -7,
	YPXFR_DBM = -8,
	YPXFR_FILE = -9,
	YPXFR_SKEW = -10,
	YPXFR_CLEAR = -11,
	YPXFR_FORCE = -12,
	YPXFR_XFRERR = -13,
	YPXFR_REFUSED = -14,
};
typedef enum YPxfrstat YPxfrstat;
bool_t xdr_YPxfrstat();


typedef char *domainname;
bool_t xdr_domainname();


typedef char *mapname;
bool_t xdr_mapname();


typedef char *peername;
bool_t xdr_peername();


typedef struct {
	u_int keydat_len;
	char *keydat_val;
} keydat;
bool_t xdr_keydat();


typedef struct {
	u_int valdat_len;
	char *valdat_val;
} valdat;
bool_t xdr_valdat();


struct YPmap_parms {
	domainname domain;
	mapname map;
	u_int ordernum;
	peername peer;
};
typedef struct YPmap_parms YPmap_parms;
bool_t xdr_YPmap_parms();


struct YPreq_key {
	domainname domain;
	mapname map;
	keydat key;
};
typedef struct YPreq_key YPreq_key;
bool_t xdr_YPreq_key();


struct YPreq_nokey {
	domainname domain;
	mapname map;
};
typedef struct YPreq_nokey YPreq_nokey;
bool_t xdr_YPreq_nokey();


struct YPreq_xfr {
	YPmap_parms map_parms;
	u_int transid;
	u_int prog;
	u_int port;
};
typedef struct YPreq_xfr YPreq_xfr;
bool_t xdr_YPreq_xfr();


struct YPresp_val {
	YPstat stat;
	valdat val;
};
typedef struct YPresp_val YPresp_val;
bool_t xdr_YPresp_val();


struct YPresp_key_val {
	YPstat stat;
	keydat key;
	valdat val;
};
typedef struct YPresp_key_val YPresp_key_val;
bool_t xdr_YPresp_key_val();


struct YPresp_master {
	YPstat stat;
	peername peer;
};
typedef struct YPresp_master YPresp_master;
bool_t xdr_YPresp_master();


struct YPresp_order {
	YPstat stat;
	u_int ordernum;
};
typedef struct YPresp_order YPresp_order;
bool_t xdr_YPresp_order();


struct YPresp_all {
	bool_t more;
	union {
		YPresp_key_val val;
	} YPresp_all_u;
};
typedef struct YPresp_all YPresp_all;
bool_t xdr_YPresp_all();


struct YPresp_xfr {
	u_int transid;
	YPxfrstat xfrstat;
};
typedef struct YPresp_xfr YPresp_xfr;
bool_t xdr_YPresp_xfr();


struct YPmaplist {
	mapname map;
	struct YPmaplist *next;
};
typedef struct YPmaplist YPmaplist;
bool_t xdr_YPmaplist();


struct YPresp_maplist {
	YPstat stat;
	YPmaplist *maps;
};
typedef struct YPresp_maplist YPresp_maplist;
bool_t xdr_YPresp_maplist();


enum YPpush_status {
	YPPUSH_SUCC = 1,
	YPPUSH_AGE = 2,
	YPPUSH_NOMAP = -1,
	YPPUSH_NODOM = -2,
	YPPUSH_RSRC = -3,
	YPPUSH_RPC = -4,
	YPPUSH_MADDR = -5,
	YPPUSH_YPERR = -6,
	YPPUSH_BADARGS = -7,
	YPPUSH_DBM = -8,
	YPPUSH_FILE = -9,
	YPPUSH_SKEW = -10,
	YPPUSH_CLEAR = -11,
	YPPUSH_FORCE = -12,
	YPPUSH_XFRERR = -13,
	YPPUSH_REFUSED = -14,
};
typedef enum YPpush_status YPpush_status;
bool_t xdr_YPpush_status();


struct YPpushresp_xfr {
	u_int transid;
	YPpush_status status;
};
typedef struct YPpushresp_xfr YPpushresp_xfr;
bool_t xdr_YPpushresp_xfr();


enum YPbind_resptype {
	YPBIND_SUCC_VAL = 1,
	YPBIND_FAIL_VAL = 2,
};
typedef enum YPbind_resptype YPbind_resptype;
bool_t xdr_YPbind_resptype();


struct YPbind_binding {
	char YPbind_binding_addr[4];
	char YPbind_binding_port[2];
};
typedef struct YPbind_binding YPbind_binding;
bool_t xdr_YPbind_binding();


struct YPbind_resp {
	YPbind_resptype YPbind_status;
	union {
		u_int YPbind_error;
		YPbind_binding YPbind_bindinfo;
	} YPbind_resp_u;
};
typedef struct YPbind_resp YPbind_resp;
bool_t xdr_YPbind_resp();

#define YPBIND_ERR_ERR 1
#define YPBIND_ERR_NOSERV 2
#define YPBIND_ERR_RESC 3

struct YPbind_setdom {
	domainname YPsetdom_domain;
	YPbind_binding YPsetdom_binding;
	u_int YPsetdom_vers;
};
typedef struct YPbind_setdom YPbind_setdom;
bool_t xdr_YPbind_setdom();


#define YPPROG ((u_long)100004)
#define YPVERS ((u_long)2)
#define YPPROC_NULL ((u_long)0)
extern void *ypproc_null_2();
#define YPPROC_DOMAIN ((u_long)1)
extern bool_t *ypproc_domain_2();
#define YPPROC_DOMAIN_NONACK ((u_long)2)
extern bool_t *ypproc_domain_nonack_2();
#define YPPROC_MATCH ((u_long)3)
extern YPresp_val *ypproc_match_2();
#define YPPROC_FIRST ((u_long)4)
extern YPresp_key_val *ypproc_first_2();
#define YPPROC_NEXT ((u_long)5)
extern YPresp_key_val *ypproc_next_2();
#define YPPROC_XFR ((u_long)6)
extern YPresp_xfr *ypproc_xfr_2();
#define YPPROC_CLEAR ((u_long)7)
extern void *ypproc_clear_2();
#define YPPROC_ALL ((u_long)8)
extern YPresp_all *ypproc_all_2();
#define YPPROC_MASTER ((u_long)9)
extern YPresp_master *ypproc_master_2();
#define YPPROC_ORDER ((u_long)10)
extern YPresp_order *ypproc_order_2();
#define YPPROC_MAPLIST ((u_long)11)
extern YPresp_maplist *ypproc_maplist_2();


#define YPPUSH_XFRRESPPROG ((u_long)0x40000000)
#define YPPUSH_XFRRESPVERS ((u_long)1)
#define YPPUSHPROC_NULL ((u_long)0)
extern void *yppushproc_null_1();
#define YPPUSHPROC_XFRRESP ((u_long)1)
extern YPpushresp_xfr *yppushproc_xfrresp_1();


#define YPBINDPROG ((u_long)100007)
#define YPBINDVERS ((u_long)2)
#define YPBINDPROC_NULL ((u_long)0)
extern void *ypbindproc_null_2();
#define YPBINDPROC_DOMAIN ((u_long)1)
extern YPbind_resp *ypbindproc_domain_2();
#define YPBINDPROC_SETDOM ((u_long)2)
extern void *ypbindproc_setdom_2();

